@@ -68,18 +68,27 @@ class PrettyHTTPExceptor(HTTPExceptor):
         relevant error tiddler, format its contents, and send out
         the text.
         """
+        status = exc.status.split(' ', 1)[0]
+        output = exc.output()
+
         headers = []
         for header, value in exc.headers():
-            if header.lower() == 'content-type':
+            if (not status.startswith('3') and
+                    header.lower() == 'content-type'):
                 value = 'text/html; charset=UTF-8'
             headers.append((header, value))
-        status = exc.status.split(' ', 1)[0]
-        status_tiddler = self._get_status_tiddler(environ, status)
+
         start_response(exc.status, headers, exc_info)
-        if exc.output():
+
+        # don't send pretty errors with 3xx responses
+        if not status.startswith('3') and output:
+            status_tiddler = self._get_status_tiddler(environ, status)
             text = format_error_tiddler(environ, status_tiddler, exc)
+        elif output:
+            return output
         else:
             text = ''
+
         return [text]
 
     def _get_status_tiddler(self, environ, status):
